@@ -41,12 +41,12 @@ sub new {
     Wx::Event::EVT_BUTTON( $self, $self->{'close'},  sub { $self->close      });
 
     Wx::Event::EVT_TEXT( $self, $self->{'text'}, sub { $self->find_first( ); $_[1]->Skip; });
-    
+
     Wx::Event::EVT_CHECKBOX( $self, $self->{'case'},  sub { $self->update_flags } );
     Wx::Event::EVT_CHECKBOX( $self, $self->{'word'},  sub { $self->update_flags } );
     Wx::Event::EVT_CHECKBOX( $self, $self->{'start'}, sub { $self->update_flags } );
     Wx::Event::EVT_CHECKBOX( $self, $self->{'regex'}, sub { $self->update_flags } );
-    
+
     Wx::Event::EVT_KEY_DOWN( $self->{'text'}, sub {
         my ($ed, $event) = @_;
         my $code = $event->GetKeyCode; # my $mod = $event->GetModifiers();
@@ -60,7 +60,7 @@ sub new {
         elsif( $event->ControlDown and $code == ord('F'))         { $self->editor->SetFocus  }
         else { $event->Skip }
     });
-    
+
     my $attr = &Wx::wxGROW | &Wx::wxTOP|&Wx::wxDOWN;
     my $sizer = Wx::BoxSizer->new( &Wx::wxHORIZONTAL );
     $sizer->AddSpacer( 10);
@@ -95,8 +95,34 @@ sub new {
     $self;
 }
 
-sub editor      { $_[0]->GetParent->{'ed'} }
-sub replace_bar { $_[0]->GetParent->{'rb'} }
+sub apply_config {
+    my ($self, $config) = @_;
+    my $config_value = $config->get_value('search');
+    $self->{'text'}->SetValue( $config_value->{'find_term'} );
+    $self->replace_bar->{'text'}->SetValue( $config_value->{'replace_term'} );
+    $self->{'case'}->SetValue( $config_value->{'case_sensitive'} );
+    $self->{'word'}->SetValue( $config_value->{'whole_word'} );
+    $self->{'start'}->SetValue( $config_value->{'word_start'} );
+    $self->{'regex'}->SetValue( $config_value->{'regular_expression'} );
+    $self->{'wrap'}->SetValue( $config_value->{'wrap_abound_document'} );
+}
+
+sub save_config {
+    my ($self, $config) = @_;
+    $config->set_value(
+        { find_term => $self->search_term,
+          replace_term => $self->replace_bar->replace_term,
+          case_sensitive => $self->{'case'}->GetValue,
+          whole_word => $self->{'word'}->GetValue,
+          word_start => $self->{'start'}->GetValue,
+          regular_expression => $self->{'regex'}->GetValue,
+          wrap_abound_document => $self->{'wrap'}->GetValue,
+        } , 'search');
+}
+
+sub editor      { $_[0]->GetParent->{'editor'} }
+sub replace_bar { $_[0]->GetParent->{'replacebar'} }
+sub search_term { $_[0]->{'text'}->GetValue }
 
 sub show {
     my ($self, $visible) = @_;
@@ -125,7 +151,7 @@ sub find_first {
     my ($start, $end) = $ed->GetSelection;
     $ed->SetSelection( 0, 0 );
     $ed->SearchAnchor;
-    my $pos = $ed->SearchNext( $self->{'flags'}, $self->{'text'}->GetValue );
+    my $pos = $ed->SearchNext( $self->{'flags'}, $self->search_term );
     $ed->SetSelection( $start, $start ) if $pos == -1;
     $ed->EnsureCaretVisible;
     $pos > -1;
@@ -134,15 +160,15 @@ sub find_first {
 sub find_prev {                                                       # key command
     my ($self) = @_;
     $self->_find_prev( $self->editor->GetSelectedText  );
-}    
+}
 sub _find_prev {                                                      # search bar command
     my ($self, $term) = @_;
     my $ed = $self->editor;
     my $wrap = $self->{'wrap'}->GetValue;
     my ($start_pos, $end_pos) = $ed->GetSelection;
-    
+
     if (defined $term and $term){ $self->{'text'}->SetValue( $term ) }
-    else                        { $term = $self->{'text'}->GetValue  }
+    else                        { $term = $self->search_term  }
 
     $ed->SetSelection( $start_pos, $start_pos );
     $ed->SearchAnchor;
@@ -160,7 +186,7 @@ sub _find_prev {                                                      # search b
 sub find_next {                                                       # key command
     my ($self) = @_;
     $self->_find_next( $self->editor->GetSelectedText  );
-}    
+}
 sub _find_next {
     my ($self, $term) = @_;
     my $ed = $self->editor;
@@ -168,7 +194,7 @@ sub _find_next {
     my ($start_pos, $end_pos) = $ed->GetSelection;
 
     if (defined $term and $term){ $self->{'text'}->SetValue( $term ) }
-    else                        { $term = $self->{'text'}->GetValue  }
+    else                        { $term = $self->search_term  }
 
     $ed->SetSelection( $end_pos, $end_pos );
     $ed->SearchAnchor;
