@@ -35,7 +35,7 @@ sub new {
     Wx::Event::EVT_KEY_DOWN( $self, sub {
         my ($self, $event) = @_;
         my $code = $event->GetKeyCode ;
-        if   ($code == &Wx::WXK_F11)        {  $self->ShowFullScreen( not $self->IsFullScreen ); say  "F11"  }
+        if   ($code == &Wx::WXK_F11)        {  $self->ShowFullScreen( not $self->IsFullScreen )  }
         else { $event->Skip }
     });
     Wx::Event::EVT_CLOSE( $self, sub {
@@ -48,7 +48,7 @@ sub new {
         $event->Skip(1);
     });
     Wx::Event::EVT_CLOSE( $self,       sub {
-        $self->config->set_value( $self->{'file'}, 'file');
+        $self->config->set_value( $self->{'file'}, 'file', 'open');
         $self->{'editor'}->save_config( $self->config );
         $self->{'searchbar'}->save_config( $self->config );
         $_[1]->Skip(1);
@@ -59,7 +59,7 @@ sub new {
     $self->{'searchbar'}->show(1);
     $self->{'replacebar'}->show(0);
 
-    $self->read_file( $self->config->get_value('file') ); # open the last opened file
+    $self->read_file( $self->config->get_value('file', 'open') ); # open the last opened file
     $self->{'editor'}->apply_config( $self->config );
     $self->{'searchbar'}->apply_config( $self->config );
 
@@ -70,6 +70,7 @@ sub config {$_[0]{'app'}{'config'}}
 
 sub new_file {
     my $self = shift;
+    Kephra::App::Window::Menu::update_recent_files_menu( $self, $self->{'file'} );
     $self->{'file'} = '';
     $self->{'editor'}->new_text( '' );
     $self->{'encoding'} = 'utf-8';
@@ -81,7 +82,8 @@ sub open_file   {
     my ($self) = @_;
     my $dir = Kephra::IO::LocalFile::dir_from_path( $self->{'file'} );
     my $file = Kephra::App::Dialog::get_file_open( $dir );
-    $self->read_file( $file ) if $file;
+    return unless $file;
+    $self->read_file( $file );
 }
 
 sub reopen_file { $_[0]->read_file( $_[0]->{'file'}, 1) }
@@ -89,6 +91,7 @@ sub reopen_file { $_[0]->read_file( $_[0]->{'file'}, 1) }
 sub read_file {
     my ($self, $file, $soft) = @_;
     return unless defined $file and -r $file;
+    Kephra::App::Window::Menu::update_recent_files_menu( $self, $self->{'file'} );
     my ($content, $encoding) = Kephra::IO::LocalFile::read( $file );
     $self->{'encoding'} = $encoding;
     $self->{'editor'}->new_text( $content, $soft );
@@ -114,14 +117,17 @@ sub save_as_file {
     my $file = Kephra::App::Dialog::get_file_save( $dir );
     return unless $file;
     $self->{'file'} = $file;
-    $self->save_file;
+    Kephra::IO::LocalFile::write( $self->{'file'},  $self->{'encoding'}, $self->{'editor'}->GetText() );
+    $self->{'editor'}->SetSavePoint;
 }
 
 sub save_under_file {
     my $self = shift;
     my $dir = Kephra::IO::LocalFile::dir_from_path( $self->{'file'} );
     my $file = Kephra::App::Dialog::get_file_save( $dir );
-    Kephra::IO::LocalFile::write( $file,  $self->{'encoding'}, $self->{'editor'}->GetText() ) if $file;
+    return unless $file;
+    Kephra::IO::LocalFile::write( $file,  $self->{'encoding'}, $self->{'editor'}->GetText() );
+    $self->{'editor'}->SetSavePoint;
 }
 
 sub set_title {
@@ -139,3 +145,4 @@ sub toggle_full_screen {
 }
 
 1;
+
